==> common-1.2.32-20230105.073525-4-sources.jar: cc/lechun/framework/common/utils/log/SqlLogEntity.java <==
package cc.lechun.framework.common.utils.log;

/**
 * Created by liqun on 2017/11/1.
 */
public class SqlLogEntity implements java.io.Serializable {

    private static final long serialVersionUID = 1L;
    private long beginTime;
    private long endTime;
    private String trans;
    private String rw;
    private String customerId;
    private String service;
    private String sqls;
    private String db;
    private long runTimes;
    private String operator;
    private String sign;

    public String getSign() {
        return sign;
    }

    public void setSign(String sign) {
        this.sign = sign;
    }

    public long getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(long beginTime) {
        this.beginTime = beginTime;
    }

    public long getEndTime() {
        return endTime;
    }

    public void setEndTime(long endTime) {
        this.endTime = endTime;
    }

    public String getTrans() {
        return trans;
    }

    public void setTrans(String trans) {
        this.trans = trans;
    }

    public String getRw() {
        return rw;
    }

    public void setRw(String rw) {
        this.rw = rw;
    }

    public String getCustomerId() {
        return customerId;
    }

    public void setCustomerId(String customerId) {
        this.customerId = customerId;
    }

    public String getService() {
        return service;
    }

    public void setService(String service) {
        this.service = service;
    }

    public String getSqls() {
        return sqls;
    }

    public void setSqls(String sqls) {
        this.sqls = sqls;
    }

    public String getDb() {
        return db;
    }

    public void setDb(String db) {
        this.db = db;
    }

    public long getRunTimes() {
        return runTimes;
    }

    public String getOperator() {
        return operator;
    }

    public void setOperator(String operator) {
        this.operator = operator;
    }

    public void setRunTimes(long runTimes) {
        this.runTimes = runTimes;
    }
}

==> common-1.3.2-20230322.072952-3-sources.jar: cc/lechun/framework/common/utils/log/SqlLogEntity.java <==
package cc.lechun.framework.common.utils.log;

/**
 * Created by liqun on 2017/11/1.
 */
public class SqlLogEntity implements java.io.Serializable {

    private static final long serialVersionUID = 1L;
    private long beginTime;
    private long endTime;
    private String trans;
    private String rw;
    private String customerId;
    private String service;
    private String sqls;
    private String db;
    private long runTimes;
    private String operator;
    private String sign;

    public String getSign() {
        return sign;
    }

    public void setSign(String sign) {
        this.sign = sign;
    }

    public long getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(long beginTime) {
        this.beginTime = beginTime;
    }

    public long getEndTime() {
        return endTime;
    }

    public void setEndTime(long endTime) {
        this.endTime = endTime;
    }

    public String getTrans() {
        return trans;
    }

    public void setTrans(String trans) {
        this.trans = trans;
    }

    public String getRw() {
        return rw;
    }

    public void setRw(String rw) {
        this.rw = rw;
    }

    public String getCustomerId() {
        return customerId;
    }

    public void setCustomerId(String customerId) {
        this.customerId = customerId;
    }

    public String getService() {
        return service;
    }

    public void setService(String service) {
        this.service = service;
    }

    public String getSqls() {
        return sqls;
    }

    public void setSqls(String sqls) {
        this.sqls = sqls;
    }

    public String getDb() {
        return db;
    }

    public void setDb(String db) {
        this.db = db;
    }

    public long getRunTimes() {
        return runTimes;
    }

    public String getOperator() {
        return operator;
    }

    public void setOperator(String operator) {
        this.operator = operator;
    }

    public void setRunTimes(long runTimes) {
        this.runTimes = runTimes;
    }
    @Override
    public String toString() {

        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", beginTime=").append(beginTime);
        sb.append(", endTime=").append(endTime);
        sb.append(", trans=").append(trans);
        sb.append(", rw=").append(rw);
        sb.append(", customerId=").append(customerId);
        sb.append(", service=").append(service);
        sb.append(", sqls=").append(sqls);
        sb.append(", db=").append(db);
        sb.append(", runTimes=").append(runTimes);
        sb.append(", operator=").append(operator);
        sb.append(", sign=").append(sign);
        sb.append("]");
        return sb.toString();
    }
}
